@@ -19,14 +19,18 @@ from contextlib import suppress
 from socket import gaierror, getaddrinfo, inet_ntoa
 from struct import pack
 
-from cloudinit import sources, subp
+from cloudinit import dmi, net, performance, sources, subp
 from cloudinit import url_helper as uhelp
 from cloudinit import util
 from cloudinit.net import dhcp
+from cloudinit.net.dhcp import NoDHCPLeaseError
+from cloudinit.net.ephemeral import EphemeralIPNetwork
 from cloudinit.sources.helpers import ec2
 
 LOG = logging.getLogger(__name__)
 
+CLOUD_STACK_DMI_NAME = "CloudStack"
+
 
 class CloudStackPasswordServerClient:
     """
@@ -64,6 +68,7 @@ class CloudStackPasswordServerClient:
         )
         return output.strip()
 
+    @performance.timed("Getting password", log_mode="always")
     def get_password(self):
         password = self._do_request("send_my_password")
         if password in ["", "saved_password"]:
@@ -75,7 +80,7 @@ class CloudStackPasswordServerClient:
 
 
 class DataSourceCloudStack(sources.DataSource):
-
+    perform_dhcp_setup = False
     dsname = "CloudStack"
 
     # Setup read_url parameters per get_url_params.
@@ -83,18 +88,13 @@ class DataSourceCloudStack(sources.DataSource):
     url_timeout = 50
 
     def __init__(self, sys_cfg, distro, paths):
-        sources.DataSource.__init__(self, sys_cfg, distro, paths)
+        super().__init__(sys_cfg, distro, paths)
         self.seed_dir = os.path.join(paths.seed_dir, "cs")
         # Cloudstack has its metadata/userdata URLs located at
         # http://<virtual-router-ip>/latest/
         self.api_ver = "latest"
-
-        self.distro = distro
-        self.vr_addr = get_vr_address(self.distro)
-        if not self.vr_addr:
-            raise RuntimeError("No virtual router found!")
-        self.metadata_address = f"http://{self.vr_addr}/"
         self.cfg = {}
+        self.vr_addr = None
 
     def _get_domainname(self):
         """
@@ -177,7 +177,7 @@ class DataSourceCloudStack(sources.DataSource):
                 self.metadata_address, "latest/meta-data/instance-id"
             )
         ]
-        start_time = time.time()
+        start_time = time.monotonic()
         url, _response = uhelp.wait_for_url(
             urls=urls,
             max_wait=url_params.max_wait_seconds,
@@ -192,7 +192,7 @@ class DataSourceCloudStack(sources.DataSource):
                 "Giving up on waiting for the metadata from %s"
                 " after %s seconds",
                 urls,
-                int(time.time() - start_time),
+                int(time.monotonic() - start_time),
             )
 
         return bool(url)
@@ -200,6 +200,11 @@ class DataSourceCloudStack(sources.DataSource):
     def get_config_obj(self):
         return self.cfg
 
+    @staticmethod
+    def ds_detect() -> bool:
+        """Check if running on this datasource"""
+        return is_platform_viable()
+
     def _get_data(self):
         seed_ret = {}
         if util.read_optional_seed(seed_ret, base=(self.seed_dir + "/")):
@@ -207,46 +212,63 @@ class DataSourceCloudStack(sources.DataSource):
             self.metadata = seed_ret["meta-data"]
             LOG.debug("Using seeded cloudstack data from: %s", self.seed_dir)
             return True
+        if self.perform_dhcp_setup:
+            primary_nic = net.find_fallback_nic()
+            LOG.debug("Attempting DHCP on: %s", primary_nic)
+            network_context = EphemeralIPNetwork(self.distro, primary_nic)
+        else:
+            network_context = util.nullcontext()
         try:
-            if not self.wait_for_metadata_service():
-                return False
-            start_time = time.time()
-            self.userdata_raw = ec2.get_instance_userdata(
-                self.api_ver, self.metadata_address
-            )
-            self.metadata = ec2.get_instance_metadata(
-                self.api_ver, self.metadata_address
-            )
-            LOG.debug(
-                "Crawl of metadata service took %s seconds",
-                int(time.time() - start_time),
-            )
-            password_client = CloudStackPasswordServerClient(self.vr_addr)
-            try:
-                set_password = password_client.get_password()
-            except Exception:
-                util.logexc(
-                    LOG,
-                    "Failed to fetch password from virtual router %s",
-                    self.vr_addr,
+            with network_context:
+                vr_addr = get_vr_address(self.distro)
+                # If vr_addr is a dict, we have the DHCP lease
+                self.vr_addr = (
+                    vr_addr.get("dhcp-server-identifier")
+                    if isinstance(vr_addr, dict)
+                    else vr_addr
                 )
-            else:
-                if set_password:
-                    self.cfg = {
-                        "ssh_pwauth": True,
-                        "password": set_password,
-                        "chpasswd": {
-                            "expire": False,
-                        },
-                    }
-            return True
+                if not self.vr_addr:
+                    raise RuntimeError("No virtual router found!")
+                self.metadata_address = f"http://{self.vr_addr}/"
+                if not self.wait_for_metadata_service():
+                    return False
+
+                return self._crawl_metadata()
+        except NoDHCPLeaseError:
+            LOG.warning("Unable to obtain a DHCP lease on %s", primary_nic)
+            return False
+        except Exception as e:
+            LOG.warning("Failed fetching metadata service: %s", str(e))
+            return False
+
+    @performance.timed("Crawling metadata", log_mode="always")
+    def _crawl_metadata(self):
+        self.userdata_raw = ec2.get_instance_userdata(
+            self.api_ver, self.metadata_address
+        )
+        self.metadata = ec2.get_instance_metadata(
+            self.api_ver, self.metadata_address
+        )
+
+        password_client = CloudStackPasswordServerClient(self.vr_addr)
+        try:
+            set_password = password_client.get_password()
         except Exception:
             util.logexc(
                 LOG,
-                "Failed fetching from metadata service %s",
-                self.metadata_address,
+                "Failed to fetch password from virtual router %s",
+                self.vr_addr,
             )
-            return False
+        else:
+            if set_password:
+                self.cfg = {
+                    "ssh_pwauth": True,
+                    "password": set_password,
+                    "chpasswd": {
+                        "expire": False,
+                    },
+                }
+        return True
 
     def get_instance_id(self):
         return self.metadata["instance-id"]
@@ -256,6 +278,18 @@ class DataSourceCloudStack(sources.DataSource):
         return self.metadata["availability-zone"]
 
 
+class DataSourceCloudStackLocal(DataSourceCloudStack):
+    """Run in init-local using a dhcp discovery prior to metadata crawl.
+
+    In init-local, no network is available. This subclass sets up minimal
+    networking with dhclient on a viable nic so that it can talk to the
+    metadata service. If the metadata service provides network configuration
+    then render the network configuration for that instance based on metadata.
+    """
+
+    perform_dhcp_setup = True  # Get metadata network config if present
+
+
 def get_data_server():
     # Returns the metadataserver from dns
     try:
@@ -328,8 +362,17 @@ def get_vr_address(distro):
     return get_default_gateway()
 
 
+def is_platform_viable() -> bool:
+    product_name = dmi.read_dmi_data("system-product-name")
+    if not product_name:
+        LOG.debug("system-product-name not available in dmi data")
+        return False
+    return product_name.startswith(CLOUD_STACK_DMI_NAME)
+
+
 # Used to match classes to dependencies
 datasources = [
+    (DataSourceCloudStackLocal, (sources.DEP_FILESYSTEM,)),
     (DataSourceCloudStack, (sources.DEP_FILESYSTEM, sources.DEP_NETWORK)),
 ]
 
