@@ -1,9 +1,10 @@
 """Ensure no Traceback when 'chef_license' is set"""
+
 import pytest
 
 from tests.integration_tests.instances import IntegrationInstance
 from tests.integration_tests.integration_settings import PLATFORM
-from tests.integration_tests.util import verify_clean_log
+from tests.integration_tests.util import verify_clean_boot, verify_clean_log
 
 USERDATA = """\
 #cloud-config
@@ -23,3 +24,4 @@ chef:
 def test_chef_license(client: IntegrationInstance):
     log = client.read_from_file("/var/log/cloud-init.log")
     verify_clean_log(log)
+    verify_clean_boot(client)
