@@ -2,7 +2,7 @@ import pytest
 
 from tests.integration_tests.instances import IntegrationInstance
 from tests.integration_tests.integration_settings import PLATFORM
-from tests.integration_tests.util import verify_clean_log
+from tests.integration_tests.util import verify_clean_boot, verify_clean_log
 
 
 def customize_client(client: IntegrationInstance):
@@ -30,3 +30,4 @@ def test_dhcp_tmp_noexec(client: IntegrationInstance):
         not in log
     )
     verify_clean_log(log)
+    verify_clean_boot(client)
