@@ -20,14 +20,15 @@ def retry(*, tries: int = 30, delay: int = 1):
             last_error = None
             for _ in range(tries):
                 try:
-                    func(*args, **kwargs)
+                    retval = func(*args, **kwargs)
                     break
                 except Exception as e:
                     last_error = e
                     time.sleep(delay)
             else:
                 if last_error:
-                    raise last_error
+                    raise TimeoutError from last_error
+            return retval
 
         return wrapper
 
