@@ -1,5 +1,8 @@
+import re
+
 import pytest
 
+from cloudinit.lifecycle import Version
 from tests.integration_tests.instances import IntegrationInstance
 from tests.integration_tests.integration_settings import PLATFORM
 from tests.integration_tests.releases import CURRENT_RELEASE, FOCAL
@@ -7,6 +10,8 @@ from tests.integration_tests.util import (
     push_and_enable_systemd_unit,
     verify_clean_boot,
     verify_clean_log,
+    verify_ordered_items_in_text,
+    wait_for_cloud_init,
 )
 
 # This works by setting up a local repository and web server
@@ -37,6 +42,18 @@ write_files:
              - python3-pip
          roles:
            - apt
+  - path: /root/playbooks/watermark.yml
+    content: |
+       ---
+       - hosts: 127.0.0.1
+         connection: local
+         become: true
+         tasks:
+           - name: create a watermark file to assert multiple playbooks run
+             copy:
+               content: |
+                 cloud-init was here
+               dest: /MULTIPLAYBOOK_RUN
   - path: /root/playbooks/roles/apt/tasks/main.yml
     content: |
        ---
@@ -94,20 +111,21 @@ ansible:
   package_name: {package}
   galaxy:
     actions:
-     - ["ansible-galaxy", "collection", "install", "community.grafana"]
+     - ["ansible-galaxy", "collection", "install", "community.elastic"]
   pull:
-    url: "http://0.0.0.0:8000/"
-    playbook_name: ubuntu.yml
-    full: true
+    - url: "http://0.0.0.0:8000/"
+      playbook_names: [ubuntu.yml, watermark.yml]
+      full: true
 """
 
-SETUP_REPO = f"cd {REPO_D}                                    &&\
-git config --global user.name auto                            &&\
-git config --global user.email autom@tic.io                   &&\
-git config --global init.defaultBranch main                   &&\
-git init {REPO_D}                                             &&\
-git add {REPO_D}/roles/apt/tasks/main.yml {REPO_D}/ubuntu.yml &&\
-git commit -m auto                                            &&\
+SETUP_REPO = f"cd {REPO_D}                                    && \
+git config --global user.name auto                            && \
+git config --global user.email autom@tic.io                   && \
+git config --global init.defaultBranch main                   && \
+git init {REPO_D}                                             && \
+git add {REPO_D}/roles/apt/tasks/main.yml {REPO_D}/ubuntu.yml && \
+git add {REPO_D}/watermark.yml                                && \
+git commit -m auto                                            && \
 (cd {REPO_D}/.git; git update-server-info)"
 
 ANSIBLE_CONTROL = """\
@@ -132,7 +150,7 @@ users:
   gecos: Ansible User
   shell: /bin/bash
   groups: users,admin,wheel,lxd
-  sudo: ALL=(ALL) NOPASSWD:ALL
+  sudo: "ALL=(ALL) NOPASSWD:ALL"
 
 # Initialize lxd using cloud-init.
 # --------------------------------
@@ -266,19 +284,31 @@ def _test_ansible_pull_from_local_server(my_client):
     assert not setup.return_code
     my_client.execute("cloud-init clean --logs")
     my_client.restart()
+    wait_for_cloud_init(my_client)
     log = my_client.read_from_file("/var/log/cloud-init.log")
     verify_clean_log(log)
     verify_clean_boot(my_client)
     output_log = my_client.read_from_file("/var/log/cloud-init-output.log")
-    assert "ok=3" in output_log
+    result = my_client.execute("ansible-pull --version").splitlines()[0]
+    ansible_match = re.search(r"[\d\/.]+", result)
+    assert ansible_match, f"Unable to parse ansible-pull version {result}"
+    ansible_version = Version.from_str(ansible_match.group(0))
+    if ansible_version >= Version(2, 12, 0):
+        verify_ansible_ok_logs = ["ok=5"]
+    else:
+        # Older ansible-pull versions have to run playbooks separately
+        verify_ansible_ok_logs = ["ok=3", "ok=2"]
+    verify_ordered_items_in_text(verify_ansible_ok_logs, output_log)
     assert "SUCCESS: config-ansible ran successfully" in log
 
     # binary location is dependent on install-type, check the filepath
     # to ensure that the installed collection directory exists
     output = my_client.execute(
-        "ls /root/.ansible/collections/ansible_collections/community/grafana"
+        "ls /root/.ansible/collections/ansible_collections/community/elastic"
     )
     assert not output.stderr.strip() and output.ok
+    playbook2_content = my_client.read_from_file("/MULTIPLAYBOOK_RUN")
+    assert "cloud-init was here" == playbook2_content
 
 
 # temporarily disable this test on jenkins until firewall rules are in place
@@ -304,7 +334,6 @@ def test_ansible_pull_pip(client: IntegrationInstance):
 @pytest.mark.user_data(
     USER_DATA + INSTALL_METHOD.format(package="ansible", method="distro")
 )
-@pytest.mark.skip("This test is currently broken and needs to be fixed")
 def test_ansible_pull_distro(client):
     push_and_enable_systemd_unit(client, "repo_server.service", REPO_SERVER)
     push_and_enable_systemd_unit(client, "repo_waiter.service", REPO_WAITER)
