@@ -19,7 +19,7 @@ class TestReadCfgPaths:
                 restore.return_value = FakeDataSource(paths=init.paths)
                 with mock.patch(
                     "cloudinit.util.read_conf_from_cmdline", return_value={}
-                ):
+                ), mock.patch("cloudinit.util.read_conf", return_value={}):
                     m_init.return_value = init
                     paths = read_cfg_paths()
                     assert paths.get_ipath() is None
