@@ -1,4 +1,6 @@
 # This file is part of cloud-init. See LICENSE file for license information.
+import logging
+
 import pytest
 
 from cloudinit import subp, util
@@ -8,7 +10,7 @@ from cloudinit.config.schema import (
     get_schema,
     validate_cloudconfig_schema,
 )
-from tests.unittests.helpers import CiTestCase, mock, skipUnlessJsonSchema
+from tests.unittests.helpers import mock, skipUnlessJsonSchema
 
 NL = "\n"
 # Module path used in mocks
@@ -21,27 +23,18 @@ class FakeCloud:
         self.distro = distro
 
 
-class TestWireGuard(CiTestCase):
-    with_logs = True
-    allowed_subp = [CiTestCase.SUBP_SHELL_TRUE]
-
-    def setUp(self):
-        super(TestWireGuard, self).setUp()
-        self.tmp = self.tmp_dir()
-
+@pytest.mark.usefixtures("fake_filesystem")
+class TestWireGuard:
     def test_readiness_probe_schema_non_string_values(self):
         """ValueError raised for any values expected as string type."""
         wg_readinessprobes = [1, ["not-a-valid-command"]]
-        errors = [
-            "Expected a string for readinessprobe at 0. Found 1",
-            "Expected a string for readinessprobe at 1."
-            " Found ['not-a-valid-command']",
-        ]
-        with self.assertRaises(ValueError) as context_mgr:
+        error = (
+            r"Expected a string for readinessprobe at 0. Found 1"
+            r"\nExpected a string for readinessprobe at 1."
+            r" Found \['not-a-valid-command'\]"
+        )
+        with pytest.raises(ValueError, match=error):
             cc_wireguard.readinessprobe_command_validation(wg_readinessprobes)
-        error_msg = str(context_mgr.exception)
-        for error in errors:
-            self.assertIn(error, error_msg)
 
     def test_suppl_schema_error_on_missing_keys(self):
         """ValueError raised reporting any missing required keys"""
@@ -50,33 +43,30 @@ class TestWireGuard(CiTestCase):
             f"Invalid wireguard interface configuration:{NL}"
             "Missing required wg:interfaces keys: config_path, content, name"
         )
-        with self.assertRaisesRegex(ValueError, match):
+        with pytest.raises(ValueError, match=match):
             cc_wireguard.supplemental_schema_validation(cfg)
 
     def test_suppl_schema_error_on_non_string_values(self):
         """ValueError raised for any values expected as string type."""
         cfg = {"name": 1, "config_path": 2, "content": 3}
-        errors = [
-            "Expected a string for wg:interfaces:config_path. Found 2",
-            "Expected a string for wg:interfaces:content. Found 3",
-            "Expected a string for wg:interfaces:name. Found 1",
-        ]
-        with self.assertRaises(ValueError) as context_mgr:
+        error = (
+            "Expected a string for wg:interfaces:config_path. Found 2\n"
+            "Expected a string for wg:interfaces:content. Found 3\n"
+            "Expected a string for wg:interfaces:name. Found 1"
+        )
+        with pytest.raises(ValueError, match=error):
             cc_wireguard.supplemental_schema_validation(cfg)
-        error_msg = str(context_mgr.exception)
-        for error in errors:
-            self.assertIn(error, error_msg)
 
     def test_write_config_failed(self):
         """Errors when writing config are raised."""
         wg_int = {"name": "wg0", "config_path": "/no/valid/path"}
 
-        with self.assertRaises(RuntimeError) as context_mgr:
+        with pytest.raises(
+            RuntimeError,
+            match="Failure writing Wireguard configuration file"
+            " /no/valid/path:\n",
+        ):
             cc_wireguard.write_config(wg_int)
-        self.assertIn(
-            "Failure writing Wireguard configuration file /no/valid/path:\n",
-            str(context_mgr.exception),
-        )
 
     @mock.patch("%s.subp.subp" % MPATH)
     def test_readiness_probe_invalid_command(self, m_subp):
@@ -92,16 +82,15 @@ class TestWireGuard(CiTestCase):
 
         m_subp.side_effect = fake_subp
 
-        with self.assertRaises(RuntimeError) as context_mgr:
-            cc_wireguard.readinessprobe(wg_readinessprobes)
-        self.assertIn(
+        error = (
             "Failed running readinessprobe command:\n"
             "not-a-valid-command: Unexpected error while"
             " running command.\n"
             "Command: -\nExit code: -\nReason: -\n"
-            "Stdout: not-a-valid-command: command not found\nStderr: -",
-            str(context_mgr.exception),
+            "Stdout: not-a-valid-command: command not found\nStderr: -"
         )
+        with pytest.raises(RuntimeError, match=error):
+            cc_wireguard.readinessprobe(wg_readinessprobes)
 
     @mock.patch("%s.subp.subp" % MPATH)
     def test_enable_wg_on_error(self, m_subp):
@@ -112,16 +101,15 @@ class TestWireGuard(CiTestCase):
             "systemctl start wg-quik@wg0 failed: exit code 1"
         )
         mycloud = FakeCloud(distro)
-        with self.assertRaises(RuntimeError) as context_mgr:
-            cc_wireguard.enable_wg(wg_int, mycloud)
-        self.assertEqual(
-            "Failed enabling/starting Wireguard interface(s):\n"
+        error = (
+            r"Failed enabling/starting Wireguard interface\(s\):\n"
             "Unexpected error while running command.\n"
             "Command: -\nExit code: -\nReason: -\n"
             "Stdout: systemctl start wg-quik@wg0 failed: exit code 1\n"
-            "Stderr: -",
-            str(context_mgr.exception),
+            "Stderr: -"
         )
+        with pytest.raises(RuntimeError, match=error):
+            cc_wireguard.enable_wg(wg_int, mycloud)
 
     @mock.patch("%s.subp.which" % MPATH)
     def test_maybe_install_wg_packages_noop_when_wg_tools_present(
@@ -138,7 +126,7 @@ class TestWireGuard(CiTestCase):
     @mock.patch("%s.subp.which" % MPATH)
     @mock.patch("%s.util.kernel_version" % MPATH)
     def test_maybe_install_wf_tools_raises_update_errors(
-        self, m_kernel_version, m_which
+        self, m_kernel_version, m_which, caplog
     ):
         """maybe_install_wireguard_packages logs and raises
         apt update errors."""
@@ -148,17 +136,16 @@ class TestWireGuard(CiTestCase):
         distro.update_package_sources.side_effect = RuntimeError(
             "Some apt error"
         )
-        with self.assertRaises(RuntimeError) as context_manager:
+        with pytest.raises(RuntimeError, match="Some apt error"):
             cc_wireguard.maybe_install_wireguard_packages(
                 cloud=FakeCloud(distro)
             )
-        self.assertEqual("Some apt error", str(context_manager.exception))
-        self.assertIn("Package update failed\nTraceback", self.logs.getvalue())
+        assert "Package update failed\nTraceback" in caplog.text
 
     @mock.patch("%s.subp.which" % MPATH)
     @mock.patch("%s.util.kernel_version" % MPATH)
     def test_maybe_install_wg_raises_install_errors(
-        self, m_kernel_version, m_which
+        self, m_kernel_version, m_which, caplog
     ):
         """maybe_install_wireguard_packages logs and raises package
         install errors."""
@@ -169,34 +156,32 @@ class TestWireGuard(CiTestCase):
         distro.install_packages.side_effect = RuntimeError(
             "Some install error"
         )
-        with self.assertRaises(RuntimeError) as context_manager:
+        with pytest.raises(RuntimeError, match="Some install error"):
             cc_wireguard.maybe_install_wireguard_packages(
                 cloud=FakeCloud(distro)
             )
-        self.assertEqual("Some install error", str(context_manager.exception))
-        self.assertIn(
-            "Failed to install wireguard-tools\n", self.logs.getvalue()
-        )
+        assert "Failed to install wireguard-tools\n" in caplog.text
 
     @mock.patch("%s.subp.subp" % MPATH)
-    def test_load_wg_module_failed(self, m_subp):
+    def test_load_wg_module_failed(self, m_subp, caplog):
         """load_wireguard_kernel_module logs and raises
         kernel modules loading error."""
         m_subp.side_effect = subp.ProcessExecutionError(
             "Some kernel module load error"
         )
-        with self.assertRaises(subp.ProcessExecutionError) as context_manager:
-            cc_wireguard.load_wireguard_kernel_module()
-        self.assertEqual(
+        error = (
             "Unexpected error while running command.\n"
             "Command: -\nExit code: -\nReason: -\n"
             "Stdout: Some kernel module load error\n"
-            "Stderr: -",
-            str(context_manager.exception),
-        )
-        self.assertIn(
-            "WARNING: Could not load wireguard module:\n", self.logs.getvalue()
+            "Stderr: -"
         )
+        with pytest.raises(subp.ProcessExecutionError, match=error):
+            cc_wireguard.load_wireguard_kernel_module()
+        assert (
+            mock.ANY,
+            logging.WARNING,
+            "Could not load wireguard module:\n" + error,
+        ) in caplog.record_tuples
 
     @mock.patch("%s.subp.which" % MPATH)
     @mock.patch("%s.util.kernel_version" % MPATH)
@@ -217,29 +202,28 @@ class TestWireGuard(CiTestCase):
         distro.install_packages.assert_called_once_with(packages)
 
     @mock.patch("%s.maybe_install_wireguard_packages" % MPATH)
-    def test_handle_no_config(self, m_maybe_install_wireguard_packages):
+    def test_handle_no_config(
+        self, m_maybe_install_wireguard_packages, caplog
+    ):
         """When no wireguard configuration is provided, nothing happens."""
         cfg = {}
         cc_wireguard.handle("wg", cfg=cfg, cloud=None, args=None)
-        self.assertIn(
-            "DEBUG: Skipping module named wg, no 'wireguard'"
-            " configuration found",
-            self.logs.getvalue(),
-        )
-        self.assertEqual(m_maybe_install_wireguard_packages.call_count, 0)
+        assert (
+            mock.ANY,
+            logging.DEBUG,
+            "Skipping module named wg, no 'wireguard' configuration found",
+        ) in caplog.record_tuples
+        assert m_maybe_install_wireguard_packages.call_count == 0
 
     def test_readiness_probe_with_non_string_values(self):
         """ValueError raised for any values expected as string type."""
         cfg = [1, 2]
-        errors = [
-            "Expected a string for readinessprobe at 0. Found 1",
-            "Expected a string for readinessprobe at 1. Found 2",
-        ]
-        with self.assertRaises(ValueError) as context_manager:
+        error = (
+            "Expected a string for readinessprobe at 0. Found 1\n"
+            "Expected a string for readinessprobe at 1. Found 2"
+        )
+        with pytest.raises(ValueError, match=error):
             cc_wireguard.readinessprobe_command_validation(cfg)
-        error_msg = str(context_manager.exception)
-        for error in errors:
-            self.assertIn(error, error_msg)
 
 
 class TestWireguardSchema:
