@@ -1,8 +1,6 @@
 # This file is part of cloud-init. See LICENSE file for license information.
 
-from tests.unittests.helpers import CiTestCase
-
-from . import _get_distro
+from tests.unittests.helpers import get_distro
 
 SYSTEM_INFO = {
     "paths": {
@@ -13,13 +11,12 @@ SYSTEM_INFO = {
 }
 
 
-class TestAzurelinux(CiTestCase):
-    with_logs = True
-    distro = _get_distro("azurelinux", SYSTEM_INFO)
+class TestAzurelinux:
+    distro = get_distro("azurelinux", SYSTEM_INFO)
     expected_log_line = "Rely on Azure Linux default network config"
 
     def test_network_renderer(self):
-        self.assertEqual(self.distro._cfg["network"]["renderers"], "networkd")
+        assert self.distro._cfg["network"]["renderers"] == "networkd"
 
     def test_get_distro(self):
-        self.assertEqual(self.distro.osfamily, "azurelinux")
+        assert self.distro.osfamily == "azurelinux"
