@@ -1,7 +1,6 @@
 # This file is part of cloud-init. See LICENSE file for license information.
 
-from tests.unittests.distros import _get_distro
-from tests.unittests.helpers import mock
+from tests.unittests.helpers import get_distro, mock
 
 M_PATH = "cloudinit.distros.openbsd."
 
@@ -9,7 +8,7 @@ M_PATH = "cloudinit.distros.openbsd."
 class TestOpenBSD:
     @mock.patch(M_PATH + "subp.subp")
     def test_add_user(self, m_subp):
-        distro = _get_distro("openbsd")
+        distro = get_distro("openbsd")
         assert True is distro.add_user("me2", uid=1234, default=False)
         assert [
             mock.call(
@@ -18,7 +17,7 @@ class TestOpenBSD:
         ] == m_subp.call_args_list
 
     def test_unlock_passwd(self, caplog):
-        distro = _get_distro("openbsd")
+        distro = get_distro("openbsd")
         distro.unlock_passwd("me2")
         assert (
             "OpenBSD password lock is not reversible, "
