@@ -7,13 +7,11 @@ from unittest import mock
 import pytest
 import responses
 
-from cloudinit import helpers
 from cloudinit.sources import DataSourceAliYun as ay
 from cloudinit.sources.helpers.aliyun import (
     convert_ecs_metadata_network_config,
 )
 from cloudinit.util import load_json
-from tests.unittests import helpers as test_helpers
 
 DEFAULT_METADATA_RAW = r"""{
   "disks": {
@@ -97,183 +95,149 @@ bootcmd:
 - echo hello world > /tmp/vendor"""
 
 
-class TestAliYunDatasource(test_helpers.ResponsesTestCase):
-    def setUp(self):
-        super(TestAliYunDatasource, self).setUp()
-        cfg = {"datasource": {"AliYun": {"timeout": "1", "max_wait": "1"}}}
-        distro = {}
-        paths = helpers.Paths({"run_dir": self.tmp_dir()})
-        self.ds = ay.DataSourceAliYun(cfg, distro, paths)
-        self.metadata_address = self.ds.metadata_urls[0]
+@pytest.fixture
+def ds(paths):
+    cfg = {"datasource": {"AliYun": {"timeout": "1", "max_wait": "1"}}}
+    distro = {}
+    return ay.DataSourceAliYun(cfg, distro, paths)
 
-    @property
-    def default_metadata(self):
-        return DEFAULT_METADATA
 
-    @property
-    def default_userdata(self):
-        return DEFAULT_USERDATA
+@pytest.fixture
+def metadata_address(ds):
+    return ds.metadata_urls[0]
 
-    @property
-    def default_vendordata(self):
-        return DEFAULT_VENDORDATA
 
-    @property
-    def metadata_url(self):
-        return (
-            os.path.join(
-                self.metadata_address,
-                self.ds.min_metadata_version,
-                "meta-data",
-            )
-            + "/"
+def register_mock_metaserver(base_url, data):
+    def register_helper(register, base_url, body):
+        if isinstance(body, str):
+            register(base_url, body)
+        elif isinstance(body, list):
+            register(base_url.rstrip("/"), "\n".join(body) + "\n")
+        elif isinstance(body, dict):
+            if not body:
+                register(base_url.rstrip("/") + "/", "not found", status=404)
+            vals = []
+            for k, v in body.items():
+                if isinstance(v, (str, list)):
+                    suffix = k.rstrip("/")
+                else:
+                    suffix = k.rstrip("/") + "/"
+                vals.append(suffix)
+                url = base_url.rstrip("/") + "/" + suffix
+                register_helper(register, url, v)
+            register(base_url, "\n".join(vals) + "\n")
+
+    register = functools.partial(responses.add, responses.GET)
+    register_helper(register, base_url, data)
+
+
+@pytest.fixture
+def regist_default_server(ds, metadata_address):
+    metadata_url = (
+        os.path.join(
+            metadata_address,
+            ds.min_metadata_version,
+            "meta-data",
         )
+        + "/"
+    )
+    register_mock_metaserver(metadata_url, DEFAULT_METADATA)
 
-    @property
-    def metadata_all_url(self):
-        return (
-            os.path.join(
-                self.metadata_address,
-                self.ds.min_metadata_version,
-                "meta-data",
-            )
-            + "/all"
-        )
+    userdata_url = os.path.join(
+        metadata_address, ds.min_metadata_version, "user-data"
+    )
+    register_mock_metaserver(userdata_url, DEFAULT_USERDATA)
 
-    @property
-    def userdata_url(self):
-        return os.path.join(
-            self.metadata_address, self.ds.min_metadata_version, "user-data"
-        )
-
-    @property
-    def vendordata_url(self):
-        return os.path.join(
-            self.metadata_address, self.ds.min_metadata_version, "vendor-data"
-        )
+    vendordata_url = os.path.join(
+        metadata_address, ds.min_metadata_version, "vendor-data"
+    )
+    register_mock_metaserver(vendordata_url, DEFAULT_USERDATA)
 
     # EC2 provides an instance-identity document which must return 404 here
     # for this test to pass.
-    @property
-    def default_identity(self):
-        return {}
+    default_identity = {}
+    identity_url = os.path.join(
+        metadata_address,
+        ds.min_metadata_version,
+        "dynamic",
+        "instance-identity",
+    )
+    register_mock_metaserver(identity_url, default_identity)
 
-    @property
-    def identity_url(self):
-        return os.path.join(
-            self.metadata_address,
-            self.ds.min_metadata_version,
-            "dynamic",
-            "instance-identity",
+    token_url = os.path.join(metadata_address, "latest", "api", "token")
+    responses.add(responses.PUT, token_url, "API-TOKEN")
+
+
+@pytest.fixture
+def regist_json_meta_path(ds, metadata_address):
+    metadata_all_url = (
+        os.path.join(
+            metadata_address,
+            ds.min_metadata_version,
+            "meta-data",
         )
+        + "/all"
+    )
+    register_mock_metaserver(metadata_all_url, DEFAULT_METADATA_RAW)
 
-    @property
-    def token_url(self):
-        return os.path.join(
-            self.metadata_address,
-            "latest",
-            "api",
-            "token",
-        )
 
-    def register_mock_metaserver(self, base_url, data):
-        def register_helper(register, base_url, body):
-            if isinstance(body, str):
-                register(base_url, body)
-            elif isinstance(body, list):
-                register(base_url.rstrip("/"), "\n".join(body) + "\n")
-            elif isinstance(body, dict):
-                if not body:
-                    register(
-                        base_url.rstrip("/") + "/", "not found", status=404
-                    )
-                vals = []
-                for k, v in body.items():
-                    if isinstance(v, (str, list)):
-                        suffix = k.rstrip("/")
-                    else:
-                        suffix = k.rstrip("/") + "/"
-                    vals.append(suffix)
-                    url = base_url.rstrip("/") + "/" + suffix
-                    register_helper(register, url, v)
-                register(base_url, "\n".join(vals) + "\n")
+class TestAliYunDatasource:
 
-        register = functools.partial(self.responses.add, responses.GET)
-        register_helper(register, base_url, data)
+    def _test_get_data(self, ds):
+        assert ds.metadata == DEFAULT_METADATA
+        assert ds.userdata_raw == DEFAULT_USERDATA.encode("utf8")
 
-    def regist_default_server(self, register_json_meta_path=True):
-        self.register_mock_metaserver(self.metadata_url, self.default_metadata)
-        if register_json_meta_path:
-            self.register_mock_metaserver(
-                self.metadata_all_url, DEFAULT_METADATA_RAW
-            )
-        self.register_mock_metaserver(self.userdata_url, self.default_userdata)
-        self.register_mock_metaserver(
-            self.vendordata_url, self.default_userdata
-        )
-
-        self.register_mock_metaserver(self.identity_url, self.default_identity)
-        self.responses.add(responses.PUT, self.token_url, "API-TOKEN")
-
-    def _test_get_data(self):
-        self.assertEqual(self.ds.metadata, self.default_metadata)
-        self.assertEqual(
-            self.ds.userdata_raw, self.default_userdata.encode("utf8")
-        )
-
-    def _test_get_sshkey(self):
+    def _test_get_sshkey(self, ds):
         pub_keys = [
             v["openssh-key"]
-            for (_, v) in self.default_metadata["public-keys"].items()
+            for (_, v) in DEFAULT_METADATA["public-keys"].items()
         ]
-        self.assertEqual(self.ds.get_public_ssh_keys(), pub_keys)
+        assert ds.get_public_ssh_keys() == pub_keys
 
-    def _test_get_iid(self):
-        self.assertEqual(
-            self.default_metadata["instance-id"], self.ds.get_instance_id()
-        )
+    def _test_get_iid(self, ds):
+        assert DEFAULT_METADATA["instance-id"] == ds.get_instance_id()
 
-    def _test_host_name(self):
-        self.assertEqual(
-            self.default_metadata["hostname"], self.ds.get_hostname().hostname
-        )
+    def _test_host_name(self, ds):
+        assert DEFAULT_METADATA["hostname"] == ds.get_hostname().hostname
 
+    @responses.activate
+    @pytest.mark.usefixtures("regist_default_server", "regist_json_meta_path")
     @mock.patch("cloudinit.sources.DataSourceEc2.util.is_resolvable")
     @mock.patch("cloudinit.sources.DataSourceAliYun._is_aliyun")
-    def test_with_mock_server(self, m_is_aliyun, m_resolv):
+    def test_with_mock_server(self, m_is_aliyun, m_resolv, ds):
         m_is_aliyun.return_value = True
-        self.regist_default_server()
-        ret = self.ds.get_data()
-        self.assertEqual(True, ret)
-        self.assertEqual(1, m_is_aliyun.call_count)
-        self._test_get_data()
-        self._test_get_sshkey()
-        self._test_get_iid()
-        self._test_host_name()
-        self.assertEqual("aliyun", self.ds.cloud_name)
-        self.assertEqual("aliyun", self.ds.platform)
-        self.assertEqual(
-            "metadata (http://100.100.100.200)", self.ds.subplatform
-        )
+        ret = ds.get_data()
+        assert True is ret
+        assert 1 == m_is_aliyun.call_count
+        self._test_get_data(ds)
+        self._test_get_sshkey(ds)
+        self._test_get_iid(ds)
+        self._test_host_name(ds)
+        assert "aliyun" == ds.cloud_name
+        assert "aliyun" == ds.platform
+        assert "metadata (http://100.100.100.200)" == ds.subplatform
 
+    @responses.activate
+    @pytest.mark.usefixtures("regist_default_server")
     @mock.patch("cloudinit.sources.DataSourceEc2.util.is_resolvable")
     @mock.patch("cloudinit.sources.DataSourceAliYun._is_aliyun")
-    def test_with_mock_server_without_json_path(self, m_is_aliyun, m_resolv):
+    def test_with_mock_server_without_json_path(
+        self, m_is_aliyun, m_resolv, ds
+    ):
         m_is_aliyun.return_value = True
-        self.regist_default_server(register_json_meta_path=False)
-        ret = self.ds.get_data()
-        self.assertEqual(True, ret)
-        self.assertEqual(1, m_is_aliyun.call_count)
-        self._test_get_data()
-        self._test_get_sshkey()
-        self._test_get_iid()
-        self._test_host_name()
-        self.assertEqual("aliyun", self.ds.cloud_name)
-        self.assertEqual("aliyun", self.ds.platform)
-        self.assertEqual(
-            "metadata (http://100.100.100.200)", self.ds.subplatform
-        )
+        ret = ds.get_data()
+        assert True is ret
+        assert 1 == m_is_aliyun.call_count
+        self._test_get_data(ds)
+        self._test_get_sshkey(ds)
+        self._test_get_iid(ds)
+        self._test_host_name(ds)
+        assert "aliyun" == ds.cloud_name
+        assert "aliyun" == ds.platform
+        assert "metadata (http://100.100.100.200)" == ds.subplatform
 
+    @responses.activate
+    @pytest.mark.usefixtures("regist_default_server", "regist_json_meta_path")
     @mock.patch("cloudinit.net.ephemeral.EphemeralIPv6Network")
     @mock.patch("cloudinit.net.ephemeral.EphemeralIPv4Network")
     @mock.patch("cloudinit.sources.DataSourceEc2.util.is_resolvable")
@@ -291,6 +255,8 @@ class TestAliYunDatasource(test_helpers.ResponsesTestCase):
         m_resolva,
         m_net4,
         m_net6,
+        ds,
+        paths,
     ):
         m_is_aliyun.return_value = True
         m_fallback_nic.return_value = "eth9"
@@ -304,66 +270,57 @@ class TestAliYunDatasource(test_helpers.ResponsesTestCase):
         m_is_bsd.return_value = False
         cfg = {"datasource": {"AliYun": {"timeout": "1", "max_wait": "1"}}}
         distro = mock.MagicMock()
-        paths = helpers.Paths({"run_dir": self.tmp_dir()})
-        self.ds = ay.DataSourceAliYunLocal(cfg, distro, paths)
-        self.regist_default_server()
-        ret = self.ds.get_data()
-        self.assertEqual(True, ret)
-        self.assertEqual(1, m_is_aliyun.call_count)
-        self._test_get_data()
-        self._test_get_sshkey()
-        self._test_get_iid()
-        self._test_host_name()
-        self.assertEqual("aliyun", self.ds.cloud_name)
-        self.assertEqual("aliyun", self.ds.platform)
-        self.assertEqual(
-            "metadata (http://100.100.100.200)", self.ds.subplatform
-        )
+        ds = ay.DataSourceAliYunLocal(cfg, distro, paths)
+        ret = ds.get_data()
+        assert True is ret
+        assert 1 == m_is_aliyun.call_count
+        self._test_get_data(ds)
+        self._test_get_sshkey(ds)
+        self._test_get_iid(ds)
+        self._test_host_name(ds)
+        assert "aliyun" == ds.cloud_name
+        assert "aliyun" == ds.platform
+        assert "metadata (http://100.100.100.200)" == ds.subplatform
 
+    @responses.activate
+    @pytest.mark.usefixtures("regist_default_server", "regist_json_meta_path")
     @mock.patch("cloudinit.sources.DataSourceAliYun._is_aliyun")
-    def test_returns_false_when_not_on_aliyun(self, m_is_aliyun):
+    def test_returns_false_when_not_on_aliyun(self, m_is_aliyun, ds):
         """If is_aliyun returns false, then get_data should return False."""
         m_is_aliyun.return_value = False
-        self.regist_default_server()
-        ret = self.ds.get_data()
-        self.assertEqual(1, m_is_aliyun.call_count)
-        self.assertEqual(False, ret)
+        ret = ds.get_data()
+        assert 1 == m_is_aliyun.call_count
+        assert False is ret
 
     def test_parse_public_keys(self):
         public_keys = {}
-        self.assertEqual(ay.parse_public_keys(public_keys), [])
+        assert ay.parse_public_keys(public_keys) == []
 
         public_keys = {"key-pair-0": "ssh-key-0"}
-        self.assertEqual(
-            ay.parse_public_keys(public_keys), [public_keys["key-pair-0"]]
-        )
+        assert ay.parse_public_keys(public_keys) == [public_keys["key-pair-0"]]
 
         public_keys = {"key-pair-0": "ssh-key-0", "key-pair-1": "ssh-key-1"}
-        self.assertEqual(
-            set(ay.parse_public_keys(public_keys)),
-            set([public_keys["key-pair-0"], public_keys["key-pair-1"]]),
+        assert set(ay.parse_public_keys(public_keys)) == set(
+            [public_keys["key-pair-0"], public_keys["key-pair-1"]]
         )
 
         public_keys = {"key-pair-0": ["ssh-key-0", "ssh-key-1"]}
-        self.assertEqual(
-            ay.parse_public_keys(public_keys), public_keys["key-pair-0"]
-        )
+        assert ay.parse_public_keys(public_keys) == public_keys["key-pair-0"]
 
         public_keys = {"key-pair-0": {"openssh-key": []}}
-        self.assertEqual(ay.parse_public_keys(public_keys), [])
+        assert ay.parse_public_keys(public_keys) == []
 
         public_keys = {"key-pair-0": {"openssh-key": "ssh-key-0"}}
-        self.assertEqual(
-            ay.parse_public_keys(public_keys),
-            [public_keys["key-pair-0"]["openssh-key"]],
-        )
+        assert ay.parse_public_keys(public_keys) == [
+            public_keys["key-pair-0"]["openssh-key"]
+        ]
 
         public_keys = {
             "key-pair-0": {"openssh-key": ["ssh-key-0", "ssh-key-1"]}
         }
-        self.assertEqual(
-            ay.parse_public_keys(public_keys),
-            public_keys["key-pair-0"]["openssh-key"],
+        assert (
+            ay.parse_public_keys(public_keys)
+            == public_keys["key-pair-0"]["openssh-key"]
         )
 
     def test_route_metric_calculated_with_multiple_network_cards(self):
@@ -428,7 +385,7 @@ class TestAliYunDatasource(test_helpers.ResponsesTestCase):
         assert "dhcp4-overrides" not in met0
 
 
-class TestIsAliYun(test_helpers.CiTestCase):
+class TestIsAliYun:
     ALIYUN_PRODUCT = "Alibaba Cloud ECS"
     read_dmi_data_expected = [mock.call("system-product-name")]
 
@@ -437,27 +394,21 @@ class TestIsAliYun(test_helpers.CiTestCase):
         """Should return true if the dmi product data has expected value."""
         m_read_dmi_data.return_value = self.ALIYUN_PRODUCT
         ret = ay._is_aliyun()
-        self.assertEqual(
-            self.read_dmi_data_expected, m_read_dmi_data.call_args_list
-        )
-        self.assertEqual(True, ret)
+        assert self.read_dmi_data_expected == m_read_dmi_data.call_args_list
+        assert True is ret
 
     @mock.patch("cloudinit.sources.DataSourceAliYun.dmi.read_dmi_data")
     def test_false_on_empty_string(self, m_read_dmi_data):
         """Should return false on empty value returned."""
         m_read_dmi_data.return_value = ""
         ret = ay._is_aliyun()
-        self.assertEqual(
-            self.read_dmi_data_expected, m_read_dmi_data.call_args_list
-        )
-        self.assertEqual(False, ret)
+        assert self.read_dmi_data_expected == m_read_dmi_data.call_args_list
+        assert False is ret
 
     @mock.patch("cloudinit.sources.DataSourceAliYun.dmi.read_dmi_data")
     def test_false_on_unknown_string(self, m_read_dmi_data):
         """Should return false on an unrelated string."""
         m_read_dmi_data.return_value = "cubs win"
         ret = ay._is_aliyun()
-        self.assertEqual(
-            self.read_dmi_data_expected, m_read_dmi_data.call_args_list
-        )
-        self.assertEqual(False, ret)
+        assert self.read_dmi_data_expected == m_read_dmi_data.call_args_list
+        assert False is ret
