@@ -15,8 +15,7 @@ import pytest
 
 from cloudinit import util
 from cloudinit.sources import DataSourceWSL as wsl
-from tests.unittests.distros import _get_distro
-from tests.unittests.helpers import does_not_raise, mock
+from tests.unittests.helpers import does_not_raise, get_distro, mock
 
 INSTANCE_NAME = "Noble-MLKit"
 GOOD_MOUNTS = {
@@ -182,18 +181,29 @@ class TestWSLHelperFunctions:
         assert files == wsl.candidate_user_data_file_names(INSTANCE_NAME)
 
     @pytest.mark.parametrize(
-        "md_content,raises,errors,warnings,md_expected",
+        "md_content,is_from_pro,raises,errors,warnings,md_expected",
         (
             pytest.param(
                 None,
+                False,
                 does_not_raise(),
                 [],
                 [],
                 {"instance-id": "iid-datasource-wsl"},
                 id="default_md_on_no_md_file",
             ),
+            pytest.param(
+                '{"instance-id":"iid-load-from-pro"}',
+                True,
+                does_not_raise(),
+                [],
+                [],
+                {"instance-id": "iid-load-from-pro"},
+                id="metadata_from_pro",
+            ),
             pytest.param(
                 "{}",
+                False,
                 pytest.raises(
                     ValueError,
                     match=(
@@ -207,6 +217,7 @@ class TestWSLHelperFunctions:
             ),
             pytest.param(
                 "{",
+                True,
                 pytest.raises(
                     ValueError,
                     match=(
@@ -221,15 +232,29 @@ class TestWSLHelperFunctions:
         ),
     )
     def test_load_instance_metadata(
-        self, md_content, raises, errors, warnings, md_expected, tmpdir, caplog
+        self,
+        md_content,
+        is_from_pro,
+        raises,
+        errors,
+        warnings,
+        md_expected,
+        tmpdir,
+        caplog,
     ):
         """meta-data file is optional. Errors are raised on invalid content."""
+        path = ".cloud-init"
+        if is_from_pro:
+            path = ".ubuntupro/.cloud-init"
+
         if md_content is not None:
-            tmpdir.join("myinstance.meta-data").write(md_content)
+            dir = tmpdir.join(path)
+            os.makedirs(dir)
+            dir.join("myinstance.meta-data").write(md_content)
         with caplog.at_level(logging.WARNING):
             with raises:
                 assert md_expected == wsl.load_instance_metadata(
-                    PurePath(tmpdir), "myinstance"
+                    tmpdir, "myinstance"
                 )
             warning_logs = "\n".join(
                 [
@@ -256,6 +281,28 @@ class TestWSLHelperFunctions:
         else:
             assert "" == error_logs
 
+    @mock.patch("cloudinit.util.subp.subp")
+    def test_landscape_supports_field(self, m_subp):
+        LANDSCAPE_HELP_OUTPUT = """\
+        Usage: landscape-config [options]
+
+        Options:
+          --version             show program's version number and exit
+          -h, --help            show this help message and exit
+          --installation-request-id Only set this value if this computer is a
+                                    instance managed by Landscape, in which
+                                    it to be the request id that Landscape
+                                    to the installation activity for the host
+          --access-group=ACCESS_GROUP
+                                Suggested access group for this computer.
+          --tags=TAGS           Comma separated list of tag names to be sent
+                                to the server.
+        """
+        m_subp.return_value = util.subp.SubpResult(LANDSCAPE_HELP_OUTPUT, "")
+        assert wsl.landscape_supports_field("non_sense") is False
+        assert wsl.landscape_supports_field("tags") is True
+        assert wsl.landscape_supports_field("installation-request-id") is True
+
 
 SAMPLE_CFG = {"datasource_list": ["NoCloud", "WSL"]}
 
@@ -317,11 +364,11 @@ class TestMergeAgentLandscapeData:
         if agent_yaml is not None:
             agent_path = tmpdir.join("agent.yaml")
             agent_path.write(agent_yaml)
-            agent_data = wsl.ConfigData(agent_path)
+            agent_data = wsl.ConfigData(agent_path, "")
         if landscape_user_data is not None:
             landscape_ud_path = tmpdir.join("instance_name.user_data")
             landscape_ud_path.write(landscape_user_data)
-            user_data = wsl.ConfigData(landscape_ud_path)
+            user_data = wsl.ConfigData(landscape_ud_path, "")
         assert expected == wsl.merge_agent_landscape_data(
             agent_data, user_data
         )
@@ -342,6 +389,10 @@ class TestWSLDataSource:
             "cloudinit.sources.DataSourceWSL.subp.which",
             return_value="/usr/bin/wslpath",
         )
+        mocker.patch(
+            "cloudinit.sources.DataSourceWSL.landscape_supports_field",
+            return_value=True,
+        )
 
     def test_metadata_id_default(self, tmpdir, paths):
         """
@@ -351,7 +402,7 @@ class TestWSLDataSource:
 
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
         ds.get_data()
@@ -374,7 +425,7 @@ class TestWSLDataSource:
 
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
         ds.get_data()
@@ -390,7 +441,7 @@ class TestWSLDataSource:
 
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -413,7 +464,7 @@ class TestWSLDataSource:
         data_path.write(f"#!/bin/sh\n{COMMAND}\n")
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -442,7 +493,7 @@ write_files:
 
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -478,7 +529,7 @@ write_files:
 
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -527,7 +578,7 @@ write_files:
         # Run the datasource
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -551,9 +602,9 @@ write_files:
     def test_interaction_with_pro(self, m_get_linux_dist, tmpdir, paths):
         """Validates the interaction of user-data and Pro For WSL agent data"""
 
-        m_get_linux_dist.return_value = SAMPLE_LINUX_DISTRO
+        m_get_linux_dist.return_value = ("ubuntu", "25.10", "plucky")
 
-        user_file = tmpdir.join(".cloud-init", "ubuntu-24.04.user-data")
+        user_file = tmpdir.join(".cloud-init", "ubuntu-25.10.user-data")
         user_file.dirpath().mkdir()
         user_file.write("#cloud-config\nwrite_files:\n- path: /etc/wsl.conf")
 
@@ -575,11 +626,16 @@ landscape:
 ubuntu_pro:
     token: testtoken"""
         )
+        SAMPLE_ID = "Nice-ID"
+        agent_metadata_path = ubuntu_pro_tmp.join(f"{INSTANCE_NAME}.meta-data")
+        agent_metadata_path.write(
+            f'{{"instance-id":"{SAMPLE_ID}"}}',
+        )
 
         # Run the datasource
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -596,6 +652,8 @@ ubuntu_pro:
         assert "ubuntu_pro" in userdata
         assert "landscape" in userdata
         assert "agenttest" in userdata
+        assert "installation_request_id" in userdata
+        assert SAMPLE_ID in userdata
 
     @mock.patch("cloudinit.util.get_linux_distro")
     def test_landscape_vs_local_user(self, m_get_linux_dist, tmpdir, paths):
@@ -620,7 +678,7 @@ package_update: true"""
         # Run the datasource
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -676,7 +734,7 @@ package_update: true"""
         # Run the datasource
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -734,7 +792,7 @@ ubuntu_pro:
         # Run the datasource
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -783,7 +841,7 @@ ubuntu_pro:
         # Run the datasource
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -842,7 +900,7 @@ package_update: true"""
         # Run the datasource
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -891,7 +949,7 @@ package_update: true"""
         # Run the datasource
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
@@ -939,7 +997,7 @@ package_update: true"""
         # Run the datasource
         ds = wsl.DataSourceWSL(
             sys_cfg=SAMPLE_CFG,
-            distro=_get_distro("ubuntu"),
+            distro=get_distro("ubuntu"),
             paths=paths,
         )
 
