@@ -2,7 +2,6 @@ import pytest
 
 from cloudinit import subp
 from conftest import UnexpectedSubpError
-from tests.unittests.helpers import CiTestCase
 
 
 class TestDisableSubpUsage:
@@ -38,36 +37,16 @@ class TestDisableSubpUsage:
         assert "allowed: whoami" in str(excinfo.value)
         subp.subp(["whoami"])
 
-    @pytest.mark.allow_subp_for("whoami", "bash")
+    @pytest.mark.allow_subp_for("whoami", "sh")
     def test_subp_usage_can_be_conditionally_reenabled_for_multiple_cmds(self):
         with pytest.raises(UnexpectedSubpError) as excinfo:
             subp.subp(["some", "args"])
-        assert "allowed: whoami,bash" in str(excinfo.value)
-        subp.subp(["bash", "-c", "true"])
+        assert "allowed: whoami,sh" in str(excinfo.value)
+        subp.subp(["sh", "-c", "true"])
         subp.subp(["whoami"])
 
     @pytest.mark.allow_all_subp
-    @pytest.mark.allow_subp_for("bash")
+    @pytest.mark.allow_subp_for("sh")
     def test_both_marks_raise_an_error(self):
         with pytest.raises(UnexpectedSubpError, match="marked both"):
-            subp.subp(["bash"])
-
-
-class TestDisableSubpUsageInTestSubclass(CiTestCase):
-    """Test that disable_subp_usage doesn't impact CiTestCase's subp logic."""
-
-    def test_using_subp_raises_exception(self):
-        with pytest.raises(Exception):
-            subp.subp(["some", "args"])
-
-    def test_typeerrors_on_incorrect_usage(self):
-        with pytest.raises(TypeError):
-            subp.subp()
-
-    def test_subp_usage_can_be_reenabled(self):
-        _old_allowed_subp = self.allow_subp
-        self.allowed_subp = True
-        try:
-            subp.subp(["bash", "-c", "true"])
-        finally:
-            self.allowed_subp = _old_allowed_subp
+            subp.subp(["sh"])
