@@ -3,27 +3,26 @@
 from unittest import mock
 
 from cloudinit import version
-from tests.unittests.helpers import CiTestCase
 
 
-class TestExportsFeatures(CiTestCase):
+class TestExportsFeatures:
     def test_has_network_config_v1(self):
-        self.assertIn("NETWORK_CONFIG_V1", version.FEATURES)
+        assert "NETWORK_CONFIG_V1" in version.FEATURES
 
     def test_has_network_config_v2(self):
-        self.assertIn("NETWORK_CONFIG_V2", version.FEATURES)
+        assert "NETWORK_CONFIG_V2" in version.FEATURES
 
 
-class TestVersionString(CiTestCase):
+class TestVersionString:
     @mock.patch(
         "cloudinit.version._PACKAGED_VERSION", "17.2-3-gb05b9972-0ubuntu1"
     )
     def test_package_version_respected(self):
         """If _PACKAGED_VERSION is filled in, then it should be returned."""
-        self.assertEqual("17.2-3-gb05b9972-0ubuntu1", version.version_string())
+        assert "17.2-3-gb05b9972-0ubuntu1" == version.version_string()
 
     @mock.patch("cloudinit.version._PACKAGED_VERSION", "@@PACKAGED_VERSION@@")
     @mock.patch("cloudinit.version.__VERSION__", "17.2")
     def test_package_version_skipped(self):
         """If _PACKAGED_VERSION is not modified, then return __VERSION__."""
-        self.assertEqual("17.2", version.version_string())
+        assert "17.2" == version.version_string()
