@@ -179,8 +179,6 @@ def get_ssh_keys():
 
     # Nice helper to add in the 'running' users key (if they have one)
     key_pth = os.path.expanduser("~/.ssh/id_rsa.pub")
-    if not os.path.isfile(key_pth):
-        key_pth = os.path.expanduser("~/.ssh/id_dsa.pub")
 
     if os.path.isfile(key_pth):
         with open(key_pth, "rb") as fh:
@@ -282,7 +280,7 @@ class MetaDataHandler:
                 return result
             else:
                 contents = []
-                for (i, key_id) in enumerate(key_ids):
+                for i, key_id in enumerate(key_ids):
                     contents.append("%s=%s" % (i, key_id))
                 return "\n".join(contents)
         elif action == "placement":
@@ -491,5 +489,3 @@ def run_server():
 
 if __name__ == "__main__":
     run_server()
-
-# vi: ts=4 expandtab
